#!/bin/bash
#
# Create CA Intermediate
# 
# 
# This function will generate a CA Intermediate
# IN: UNIQ_ID_CA, SERIAL
#
PARAM1=$1
PARAM2=$2

usage() {
  echo
  echo "Generate a new certificate"
  echo
  echo "This program will generate a new certificate authority intermediate"
  echo "Requires the file ca-i.pem that is used to sign the certificates"
  echo "The script requires a CA Intermediate certificate used to sign the client"
  echo ""
  echo ""
  echo ""
  echo
  echo "Generate a new certificate"
  echo "  usage:   gen_server.sh  <CA Intermediate> <Org URL> <Serial>"
  echo
  echo "  example: gen_server.sh  ca_i_skunkworks.acme.xyz_10001.crt.pem \\"
  echo "                          skunkworks.acme.xyz \\"
  echo "                          10052 \\"
  echo
  exit 1
}

error_no_ca_file() {
  echo_block "ERROR: missing ca-i.pem"
  usage
}

error_no_serial() {
  echo_block "ERROR: missing SERIAL file"
  usage
}

get_serial() {
  filename="SERIAL"
  read -r line
  SERIAL=$line
  SERIAL=$((SERIAL+1))
}


main() {
  if [[ ! -f ca-i.pem ]]; then
    error_no_ca_file
  fi
  if [[ ! -f SERIAL ]]; then
    error_no_serial
  fi

  if [[ -n $PARAM1 ]] || [[ -n $PARAM2 ]]; then
    generate_client $PARAM1 $PARAM2
  else
    usage
  fi
}

main
